@@ -1,10 +1,10 @@
 package Moose::Exception::InvalidAttributeDefinition;
 
-# ABSTRACT: Exceptions for invalid attribute definitions.
+# ABSTRACT: MooseX::Extended exception for invalid attribute definitions.
 
 use Moose;
 extends 'Moose::Exception';
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 with 'Moose::Exception::Role::Class';
 
 has 'attribute_name' => (
@@ -25,11 +25,17 @@ __END__
 
 =head1 NAME
 
-Moose::Exception::InvalidAttributeDefinition - Exceptions for invalid attribute definitions.
+Moose::Exception::InvalidAttributeDefinition - MooseX::Extended exception for invalid attribute definitions.
 
 =head1 VERSION
 
-version 0.05
+version 0.06
+
+=head1 WHY NOT MOOSEX?
+
+This is not called C<MooseX::Exception::InvalidAttributeDefinition> because
+L<Moose::Util>'s C<throw_exception> function assumes that all exceptions begin
+with C<Moose::Exception::>.
 
 =head1 AUTHOR
 
