@@ -11,7 +11,7 @@ use Types::Standard qw(
   slurpy
 );
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our @EXPORT_OK;
 
 BEGIN {
@@ -25,6 +25,7 @@ BEGIN {
         'compile_named',    # from Type::Params
         'slurpy',
     );
+    our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 }
 
 1;
@@ -41,11 +42,12 @@ MooseX::Extended::Types - Keep our type tools organized
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
-    package MooseX::Extended::Types;
+    use MooseX::Extended;
+    use MooseX::Extended::Types;
 
     use MooseX::Extended::Types qw(
       ArrayRef
@@ -57,11 +59,23 @@ version 0.05
       compile
     );
 
+As a convenience, if you're using L<MooseX::Extended>, you can do this:
+
+    use MooseX::Extended types => [qw(
+      ArrayRef
+      Dict
+      Enum
+      HashRef
+      InstanceOf
+      Str
+      compile
+    )];
+
 =head1 DESCRIPTION
 
-A basic set of useful types for C<MooseX::Extended>. Using these is preferred
-to using using strings due to runtime versus compile-time failures. For
-example:
+A basic set of useful types for C<MooseX::Extended>, as provided by
+L<Type::Tiny>. Using these is preferred to using using strings due to runtime
+versus compile-time failures. For example:
 
     # fails at runtime, if ->name is set
     param name => ( isa => 'StR' );
