@@ -1,6 +1,4 @@
 package Not::Corinna::Role::Created {
-    use MooseX::Extended::Role;
-    use MooseX::Extended::Types qw(PositiveInt);
-
+    use MooseX::Extended::Role types => ['PositiveInt'];
     field created => ( isa => PositiveInt, default => sub {time} );
 }
